@@ -89,10 +89,10 @@ dcc_check_timeouts (void)
 		dcc = (struct DCC *) list->data;
 		next = list->next;
 
-		if (dcc->dccstat == STAT_ACTIVE)
+		switch (dcc->dccstat)
 		{
+		case STAT_ACTIVE:
 			dcc_calc_cps (dcc);
-
 			switch (dcc->type)
 			{
 			case TYPE_SEND:
@@ -102,11 +102,7 @@ dcc_check_timeouts (void)
 				fe_dcc_update_recv (dcc);
 				break;
 			}
-		}
 
-		switch (dcc->dccstat)
-		{
-		case STAT_ACTIVE:
 			if (dcc->type == TYPE_SEND || dcc->type == TYPE_RECV)
 			{
 				if (prefs.dccstalltimeout > 0)
@@ -613,7 +609,7 @@ dcc_send_data (GIOChannel *source, GIOCondition condition, struct DCC *dcc)
 		goto abortit;
 	sent = send (sok, buf, len, 0);
 
-	if (send < 0 && !(would_block ()))
+	if (sent < 0 && !(would_block ()))
 	{
 abortit:
 		EMIT_SIGNAL (XP_TE_DCCSENDFAIL, dcc->serv->front_session,
@@ -701,7 +697,7 @@ dcc_accept (GIOChannel *source, GIOCondition condition, struct DCC *dcc)
 	char host[128];
 	struct sockaddr_in CAddr;
 	int sok;
-	size_t len;
+	socklen_t len;
 
 	len = sizeof (CAddr);
 	sok = accept (dcc->sok, (struct sockaddr *) &CAddr, &len);
@@ -748,10 +744,10 @@ dcc_accept (GIOChannel *source, GIOCondition condition, struct DCC *dcc)
 static int
 dcc_listen_init (struct DCC *dcc, session *sess)
 {
-	size_t len;
 	unsigned long my_addr;
 	struct sockaddr_in SAddr;
 	int i, bindretval = -1;
+	socklen_t len;
 
 	dcc->sok = socket (AF_INET, SOCK_STREAM, 0);
 	if (dcc->sok == -1)
@@ -832,6 +828,7 @@ dcc_listen_init (struct DCC *dcc, session *sess)
 static struct session *dccsess;
 static char *dccto;				  /* lame!! */
 static char *dcctbuf;
+static int recursive = FALSE;
 
 static void
 dcc_send_wild (char *file)
@@ -845,30 +842,40 @@ void
 dcc_send (struct session *sess, char *tbuf, char *to, char *file)
 {
 	struct stat st;
-	struct DCC *dcc = new_dcc ();
-	if (!dcc)
-		return;
+	struct DCC *dcc;
 
-	dcc->file = expand_homedir (file);
+	file = expand_homedir (file);
 
-	if (strchr (dcc->file, '*') || strchr (dcc->file, '?'))
+	if (!recursive && (strchr (file, '*') || strchr (file, '?')))
 	{
 		char path[256];
 		char wild[256];
 
-		strcpy (wild, file_part (dcc->file));
-		path_part (dcc->file, path);
+		strcpy (wild, file_part (file));
+		path_part (file, path);
 		path[strlen (path) - 1] = 0;	/* remove trailing slash */
+
 		dccsess = sess;
 		dccto = to;
 		dcctbuf = tbuf;
+
+		free (file);
+
+		recursive = TRUE;
 		for_files (path, wild, dcc_send_wild);
-		dcc_close (dcc, 0, TRUE);
+		recursive = FALSE;
+
 		return;
 	}
-	if (stat (dcc->file, &st) != -1)
+
+	dcc = new_dcc ();
+	if (!dcc)
+		return;
+	dcc->file = file;
+
+	if (stat (file, &st) != -1)
 	{
-		if (*file_part (dcc->file) && !S_ISDIR (st.st_mode))
+		if (*file_part (file) && !S_ISDIR (st.st_mode))
 		{
 			if (st.st_size > 0)
 			{
@@ -877,7 +884,7 @@ dcc_send (struct session *sess, char *tbuf, char *to, char *file)
 				dcc->dccstat = STAT_QUEUED;
 				dcc->size = st.st_size;
 				dcc->type = TYPE_SEND;
-				dcc->fp = open (dcc->file, OFLAGS | O_RDONLY);
+				dcc->fp = open (file, OFLAGS | O_RDONLY);
 				if (dcc->fp != -1)
 				{
 					if (dcc_listen_init (dcc, sess))
