@@ -392,8 +392,10 @@ static int cmd_list (struct session *sess, char *tbuf, char *word[],
 							char *word_eol[]);
 static int cmd_load (struct session *sess, char *tbuf, char *word[],
 							char *word_eol[]);
-int cmd_loaddll (struct session *sess, char *tbuf, char *word[],
+#ifdef USE_PLUGIN
+static int cmd_loaddll (struct session *sess, char *tbuf, char *word[],
 					  char *word_eol[]);
+#endif
 static int cmd_lagcheck (struct session *sess, char *tbuf, char *word[],
 							 char *word_eol[]);
 static int cmd_mdeop (struct session *sess, char *tbuf, char *word[],
@@ -434,8 +436,10 @@ static int cmd_quote (struct session *sess, char *tbuf, char *word[],
 							 char *word_eol[]);
 static int cmd_reconnect (struct session *sess, char *tbuf, char *word[],
 								  char *word_eol[]);
-int cmd_rmdll (struct session *sess, char *tbuf, char *word[],
+#ifdef USE_PLUGIN
+static int cmd_rmdll (struct session *sess, char *tbuf, char *word[],
 					char *word_eol[]);
+#endif
 static int cmd_say (struct session *sess, char *tbuf, char *word[],
 						  char *word_eol[]);
 int cmd_scpinfo (struct session *sess, char *tbuf, char *word[],
@@ -467,7 +471,7 @@ static int cmd_voice (struct session *sess, char *tbuf, char *word[],
 static int cmd_flushq (struct session *sess, char *tbuf, char *word[],
 							  char *word_eol[]);
 
-struct commands xc_cmds[] = {
+const struct commands xc_cmds[] = {
 
 	{"ADDBUTTON", cmd_addbutton, 0, 0,
 	 N_("/ADDBUTTON <name> <action>, adds a button under the user-list\n")},
