@@ -1,4 +1,4 @@
-extern struct commands xc_cmds[];
+extern const struct commands xc_cmds[];
 
 void user2serv (unsigned char *s);
 void serv2user (unsigned char *s);
