@@ -1225,6 +1225,9 @@ static XS (XS_IRC_dcc_list)
 
 	while (list)
 	{
+		/* Make sure there is room on the stack */
+		EXTEND (SP, i + 9);
+
 		dcc = (struct DCC *) list->data;
 		XST_mPV (i, dcc->nick);
 		i++;
