@@ -83,7 +83,7 @@ static void
 close_socket (int sok)
 {
 	/* close the socket in 5 seconds so the QUIT message is not lost */
-	fe_timeout_add (5000, close_socket_cb, (void *) sok);
+	fe_timeout_add (5000, close_socket_cb, GINT_TO_POINTER (sok));
 }
 
 static void
@@ -396,8 +396,8 @@ read_data (GIOChannel *source, GIOCondition condition, server *serv)
 
 	while (1)
 	{
-		if (!EMIT_SIGNAL (XP_IF_RECV, &len, (void *) sok, &lbuf,
-								(void *) ((sizeof (lbuf)) - 2), NULL, 0))
+		if (!EMIT_SIGNAL (XP_IF_RECV, &len, GINT_TO_POINTER (sok), &lbuf,
+								GINT_TO_POINTER (sizeof (lbuf) - 2), NULL, 0))
 		{
 #ifdef USE_OPENSSL
 			if (!serv->ssl)
@@ -859,6 +859,7 @@ traverse_socks5 (int sok, char *serverAddr, int port)
 	*((unsigned short *) (sc2 + 5 + addrlen)) = htons (port);
 
 	send (sok, sc2, packetlen, 0);
+	free (sc2);
 	/* consume all of the reply */
 	if (recv (sok, buf, 4, 0) != 4)
 		return 1;
