@@ -507,18 +507,18 @@ static char *pevt_chansetlimit_help[] = {
 };
 
 static char *pevt_chanop_help[] = {
+	N_("The nick of the person who did the op'ing"),
 	N_("The nick of the person who has been op'ed"),
-	N_("The nick of the person of did the op'ing"),
 };
 
 static char *pevt_chanhop_help[] = {
+	N_("The nick of the person who did the halfop'ing"),
 	N_("The nick of the person who has been halfop'ed"),
-	N_("The nick of the person of did the halfop'ing"),
 };
 
 static char *pevt_chanvoice_help[] = {
+	N_("The nick of the person who did the voice'ing"),
 	N_("The nick of the person who has been voice'ed"),
-	N_("The nick of the person of did the voice'ing"),
 };
 
 static char *pevt_chanban_help[] = {
@@ -830,15 +830,6 @@ static char *pevt_discon_help[] = {
 	N_("Error"),
 };
 
-struct text_event
-{
-	char *name;
-	char **help;
-	char *def;
-	int num_args;
-	char *sound;
-};
-
 /* *BBIIGG* struct ahead!! --AGL */
 
 struct text_event te[] = {
@@ -1652,7 +1643,7 @@ textsignal_handler (struct session *sess, void *b, void *c,
 	 */
 
 	char *args[8];
-	int numargs, i;
+	int numargs;
 
 	if (!sess)
 		return 0;
@@ -1664,7 +1655,6 @@ textsignal_handler (struct session *sess, void *b, void *c,
 		abort ();
 	}
 	numargs = te[current_signal].num_args;
-	i = 0;
 
 #ifdef USE_PERL
 	if (perl_print (te[current_signal].name, sess, b, c, d, e))
