@@ -686,7 +686,7 @@ country (char *hostname)
 		char *country;
 	}
 	Domain;
-	static Domain domain[] = {
+	static const Domain domain[] = {
 		{"AD", N_("Andorra") },
 		{"AE", N_("United Arab Emirates") },
 		{"AF", N_("Afghanistan") },
