@@ -14,26 +14,26 @@
 #undef tolower
 #define tolower(c) (tolowertab[(unsigned char)(c)])
 
-#undef toupper
-#define toupper(c) (touppertab[(unsigned char)(c)])
-
 #define strcasecmp      rfc_casecmp
 #define strncasecmp     rfc_ncasecmp
 
-extern char *expand_homedir (char *file);
-extern void path_part (char *file, char *path);
-extern int match (const char *mask, const char *string);
-extern char *file_part (char *file);
-extern int for_files (char *dirname, char *mask, void callback (char *file));
-extern int rfc_casecmp (char *, char *);
-extern int rfc_ncasecmp (char *, char *, int);
 extern unsigned char tolowertab[];
-extern unsigned char touppertab[];
-extern void toupperStr (char *str);
-extern void tolowerStr (char *str);
-extern int buf_get_line (char *, char **, int *, int len);
-extern char *nocasestrstr (char *text, char *tofind);
-extern char *country (char *);
-extern int is_channel (char *string);
-extern char *get_cpu_str (int color);
-extern int util_exec (char *cmd);
+
+char *expand_homedir (char *file);
+void path_part (char *file, char *path);
+int match (const char *mask, const char *string);
+char *file_part (char *file);
+int for_files (char *dirname, char *mask, void callback (char *file));
+int rfc_casecmp (char *, char *);
+int rfc_ncasecmp (char *, char *, int);
+void toupperStr (char *str);
+void tolowerStr (char *str);
+int buf_get_line (char *, char **, int *, int len);
+char *nocasestrstr (char *text, char *tofind);
+char *country (char *);
+char *get_cpu_str (void);
+int util_exec (char *cmd);
+unsigned char *strip_color (unsigned char *text);
+char *errorstring (int err);
+int waitline (int sok, char *buf, int bufsize);
+unsigned long make_ping_time (void);
