@@ -112,8 +112,8 @@ tcp_send_real (struct server *serv, char *buf, int len)
 
 	fe_add_rawlog (serv, tbuf, TRUE);
 
-	if (!EMIT_SIGNAL (XP_IF_SEND, (void *) serv->sok, tbuf, (void *)len,
-							NULL, NULL, 0))
+	if (!EMIT_SIGNAL (XP_IF_SEND, GINT_TO_POINTER (serv->sok), tbuf,
+							GINT_TO_POINTER (len), NULL, NULL, 0))
 	{
 #ifdef USE_OPENSSL
 		if (!serv->ssl)
@@ -974,7 +974,6 @@ save_away_message (struct server *serv, char *nick, char *msg)
 
 #ifdef WIN32
 #define defaultconf_urlhandlers \
-	"NAME Open URL\n"							"CMD !start %s\n\n"\
 	"NAME Connect as IRC server\n"		"CMD /newserver %s\n\n"
 #else
 #define defaultconf_urlhandlers _( \
@@ -1107,7 +1106,7 @@ xchat_exec (char *cmd)
 	if (pid != -1)
 	/* zombie avoiding system. Don't ask! it has to be like this to work
       with zvt (which overrides the default handler) */
-		fe_timeout_add (1000, child_handler, (void *)pid);
+		fe_timeout_add (1000, child_handler, GINT_TO_POINTER (pid));
 #endif
 }
 
