@@ -92,7 +92,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	about_style->font = gdk_font_load ("fixed");
 
 	about = gtk_window_new (GTK_WINDOW_DIALOG);
-	gtk_window_position (GTK_WINDOW (about), GTK_WIN_POS_CENTER);
+	gtk_window_set_position (GTK_WINDOW (about), GTK_WIN_POS_CENTER);
 	gtk_window_set_title (GTK_WINDOW (about), _("About X-Chat"));
 	gtk_container_set_border_width (GTK_CONTAINER (about), 6);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy",
