@@ -129,7 +129,7 @@ static int key_action_put_history (GtkWidget * wid, GdkEventKey * evt,
 static GtkWidget *key_dialog;
 static struct key_binding *keys_root = NULL;
 
-static struct key_action key_actions[KEY_MAX_ACTIONS + 1] = {
+static const struct key_action key_actions[KEY_MAX_ACTIONS + 1] = {
 
 	{key_action_handle_command, "Run Command",
 	 N_("The \002Run Command\002 action runs the data in Data 1 as if it has been typed into the entry box where you pressed the key sequence. Thus it can contain text (which will be sent to the channel/person), commands or user commands. When run all \002\\n\002 characters in Data 1 are used to deliminate seperate commands so it is possible to run more than one command. If you want a \002\\\002 in the actual text run then enter \002\\\\\002")},
@@ -472,11 +472,11 @@ key_dialog_sel_row (GtkWidget * clist, gint row, gint column,
 			PrintTextRaw (key_dialog_text, _(key_actions[kb->action].help), 0);
 		}
 	}
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (key_dialog_tog_c),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (key_dialog_tog_c),
 										  (kb->mod & STATE_CTRL) == STATE_CTRL);
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (key_dialog_tog_s),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (key_dialog_tog_s),
 										  (kb->mod & STATE_SHIFT) == STATE_SHIFT);
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (key_dialog_tog_a),
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (key_dialog_tog_a),
 										  (kb->mod & STATE_ALT) == STATE_ALT);
 
 	if (kb->data1)
@@ -697,7 +697,7 @@ key_dialog_show ()
 		gtk_widget_show (wid3);
 		gtk_menu_append (GTK_MENU (wid2), wid3);
 		gtk_signal_connect (GTK_OBJECT (wid3), "activate",
-								  GTK_SIGNAL_FUNC (key_dialog_sel_act), (void *) i);
+								  GTK_SIGNAL_FUNC (key_dialog_sel_act), GINT_TO_POINTER (i));
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (wid), wid2);
@@ -729,7 +729,7 @@ key_dialog_show ()
 
 	wid = gtk_xtext_new (0, 0);
 	gtk_xtext_set_palette (GTK_XTEXT (wid), colors);
-	gtk_xtext_set_font (GTK_XTEXT (wid), font_normal, 0);
+	gtk_xtext_set_font (GTK_XTEXT (wid), font_normal);
 	gtk_xtext_set_background (GTK_XTEXT (wid),
 									  channelwin_pix,
 									  prefs.transparent, prefs.tint);
@@ -1678,7 +1678,7 @@ tab_nick_comp (GtkWidget *t, int shift)
 {
 	struct session *sess;
 	struct User *user, *match_user = NULL;
-	char *text, not_nick_chars[5] = { 0, '.', '?', ' ', 0};
+	char *text, not_nick_chars[5] = { ' ', '.', '?', 0, 0};
 	int len, slen, first, i, cursor_pos, match_count = 0, match_pos = 0;
 	char buf[2048], nick_buf[2048], *b4 = NULL, *c5 = NULL;
 	char *match_text = NULL, *current_nick = NULL;
@@ -1707,7 +1707,7 @@ tab_nick_comp (GtkWidget *t, int shift)
 	len = strlen (text);
 
 	/* Is the text more than just a nick? */
-	not_nick_chars[0] = prefs.nick_suffix[0];
+	not_nick_chars[3] = prefs.nick_suffix[0];
 
 	if (strcspn (text, not_nick_chars) != len)
 	{
