@@ -254,6 +254,7 @@ fe_set_channel (struct session *sess)
 		if (prefs.truncchans && strlen (sess->channel) > prefs.truncchans)
 		{
 			buf = malloc (strlen (sess->channel) + 4);
+			buf[0] = 0;
 			snprintf (buf, prefs.truncchans - 1, "%s", sess->channel);
 			strcat (buf, "..");
 			gtk_label_set_text (GTK_LABEL (sess->gui->changad), buf);
@@ -283,6 +284,7 @@ fe_clear_channel (struct session *sess)
 	{
 		if (prefs.truncchans && strlen (sess->waitchannel) > prefs.truncchans)
 		{
+			tbuf[0] = 0;
 			snprintf (tbuf, prefs.truncchans, "(%s", sess->waitchannel);
 			strcat (tbuf, "..)");
 		} else
@@ -409,7 +411,7 @@ ul_button_rel (GtkWidget * widget, GdkEventButton * even,
 			nick = find_selected_nick (sess);
 			if (nick)
 			{
-				snprintf (buf, sizeof (buf), "%s: ", nick);
+				snprintf (buf, sizeof (buf), "%s%c ", nick, prefs.nick_suffix[0]);
 				gtk_entry_set_text (GTK_ENTRY (sess->gui->inputgad), buf);
 				gtk_widget_grab_focus (sess->gui->inputgad);
 			}
@@ -417,8 +419,8 @@ ul_button_rel (GtkWidget * widget, GdkEventButton * even,
 	}
 }
 
-void
-focus_in (GtkWindow * win, GtkWidget * wid, session *sess)
+gboolean
+focus_in (GtkWindow * win, GdkEventFocus *event, session *sess)
 {
 	if (!sess)
 	{
@@ -448,6 +450,8 @@ focus_in (GtkWindow * win, GtkWidget * wid, session *sess)
 		if (prefs.treeview)
 			tree_default_style (sess);
 	}
+
+	return FALSE;
 }
 
 static int
@@ -496,7 +500,7 @@ flagl_hit (GtkWidget * wid, struct session *sess)
 			{
 				gtkutil_simpledialog (_("User limit must be a number!\n"));
 				gtk_entry_set_text (GTK_ENTRY (sess->gui->limit_entry), "");
-				gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (wid), FALSE);
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), FALSE);
 				return;
 			}
 			sprintf (outbuf, "MODE %s +l %d\r\n", sess->channel,
@@ -590,7 +594,7 @@ limit_entry (GtkWidget * igad, struct session *sess)
 		{
 			gtk_entry_set_text (GTK_ENTRY (igad), "");
 			gtkutil_simpledialog (_("User limit must be a number!\n"));
-			gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (sess->gui->flag_l),
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sess->gui->flag_l),
 												  FALSE);
 			return;
 		}
@@ -857,7 +861,7 @@ maingui_create_textlist (struct session *sess, GtkWidget * leftpane)
 		((GtkXText *) sess->gui->textgad)->time_stamp = TRUE;
 
 	gtk_xtext_set_palette (GTK_XTEXT (sess->gui->textgad), colors);
-	gtk_xtext_set_font (GTK_XTEXT (sess->gui->textgad), font_normal, 0);
+	gtk_xtext_set_font (GTK_XTEXT (sess->gui->textgad), font_normal);
 	gtk_xtext_set_background (GTK_XTEXT (sess->gui->textgad),
 									  channelwin_pix, prefs.transparent, prefs.tint);
 
@@ -996,7 +1000,7 @@ userlist_hide (GtkWidget *igad, session *sess)
 	if (sess->userlisthidden)
 	{
 		if (igad)
-			gtk_label_set (GTK_LABEL (GTK_BIN (igad)->child), ">");
+			gtk_label_set_text (GTK_LABEL (GTK_BIN (igad)->child), ">");
 		if (sess->gui->paned)
 			gtk_paned_set_position (GTK_PANED (sess->gui->paned),
 											sess->userlisthidden);
@@ -1007,7 +1011,7 @@ userlist_hide (GtkWidget *igad, session *sess)
 	} else
 	{
 		if (igad)
-			gtk_label_set (GTK_LABEL (GTK_BIN (igad)->child), "<");
+			gtk_label_set_text (GTK_LABEL (GTK_BIN (igad)->child), "<");
 		if (sess->gui->paned)
 		{
 			sess->userlisthidden = GTK_PANED (sess->gui->paned)->handle_xpos + 3;
@@ -1523,7 +1527,7 @@ gui_create_toolbox (session *sess, GtkWidget *box)
 		wid = toolbox_button ("  ", 0, toolbox, 0);
 		gtk_widget_set_style (wid, style);
 		gtk_signal_connect (GTK_OBJECT (wid), "clicked",
-								  GTK_SIGNAL_FUNC (toolbox_color), (gpointer) i);
+								  GTK_SIGNAL_FUNC (toolbox_color), GINT_TO_POINTER (i));
 		gtk_style_unref (style);
 	}
 
