@@ -576,7 +576,7 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 																		editnode);
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (sleditwin), vbox);
-	gtk_container_border_width (GTK_CONTAINER (sleditwin), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (sleditwin), 5);
 	gtk_widget_show (vbox);
 
 	hbox = gtk_hbox_new (TRUE, 0);
@@ -598,7 +598,7 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 	gtk_widget_show (frame);
 
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 	gtk_container_add (GTK_CONTAINER (frame), hbox);
 	gtk_widget_show (hbox);
 
@@ -1068,14 +1068,14 @@ connect_clicked (GtkWidget * wid, struct session *sess)
 		(myconn.flags & ACCEPT_INVALID_CERT) ? TRUE : FALSE;
 #endif
 
+	connect_server (sess, myconn.server, myconn.port, FALSE);
+
 	if (myconn.eom_cmd[0])
 	{
 		if (serv->eom_cmd)
 			free (serv->eom_cmd);
 		serv->eom_cmd = strdup (myconn.eom_cmd);
 	}
-
-	connect_server (sess, myconn.server, myconn.port, FALSE);
 }
 
 /*
@@ -1190,7 +1190,7 @@ fe_open_serverlist (session *sess, int auto_connect, int dont_show)
 	gtk_window_set_wmclass (GTK_WINDOW (slwin), "servlist", "X-Chat");
 	wins_set_icon (slwin);
 
-	gtk_container_border_width (GTK_CONTAINER (slwin), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (slwin), 5);
 	vbox = gtk_vbox_new (FALSE, 1);
 	gtk_container_add (GTK_CONTAINER (slwin), vbox);
 
