@@ -25,7 +25,7 @@ struct defaultserv
 	int port;
 };
 
-static struct defaultserv dserv[] =
+static const struct defaultserv dserv[] =
 {
 	{"", "SUB", "ChatJunkiesNet", 1},
 	{"#linux", "irc.xchat.org", "ChatJunkiesNet Random Server #linux", 6667},
@@ -463,6 +463,23 @@ static struct defaultserv dserv[] =
 	{"#cyberarmy", "irc.cyberarmy.com", "irc.cyberarmy.com", 6667},
 	{"", "ENDSUB", "", 0},
 
+	{"", "SUB", "2600net", 0},
+	{"", "irc.2600.net", "irc.2600.net - main server", 6667},
+	{"", "irc.dc2600.com", "irc.dc2600.com", 6667},
+	{"", "irc.nyc2600.com", "irc.nyc2600.com", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "RealmNET", 0},
+	{"", "irc.realmnet.com", "RealmNET: Random server", 6667},
+	{"", "irc.eu.realmnet.com", "RealmNET: Random server", 6667},
+	{"", "irc.us.realmnet.com", "RealmNET: Random US server", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "Freeworld IRC Network", 0},
+	{"", "kabel.freeworld.nu", "Pottstown, PA", 6667},
+	{"", "irc.freeworld.nu", "Reston, VA", 6667},
+	{"", "ENDSUB", "", 0},
+
 /*	{"", "SUB", "", 0},
 	{"", "", "", 6667},
 	{"", "ENDSUB", "", 0},*/
