@@ -137,7 +137,7 @@ settings_create_optmenu (GtkWidget *table, char *label, char **text,
 	i = 0;
 	while (text[i])
 	{
-		menu_quick_item_with_callback (callback, text[i], menu, (void *) i);
+		menu_quick_item_with_callback (callback, text[i], menu, GINT_TO_POINTER (i));
 		i++;
 	}
 
@@ -413,7 +413,7 @@ settings_create_page (GtkWidget * book, gchar * book_label, GtkWidget * ctree,
 	*node = gtk_ctree_insert_node (GTK_CTREE (ctree), parent, NULL, titles, 0,
 											 NULL, NULL, NULL, NULL, FALSE, FALSE);
 	gtk_ctree_node_set_row_data (GTK_CTREE (ctree), *node,
-										  (gpointer) page_index);
+										  GINT_TO_POINTER (page_index));
 
 	/* call the draw func if there is one */
 	if (draw_func)
@@ -685,7 +685,7 @@ settings_ok_clicked (GtkWidget * wid, struct session *sess)
 			GTK_XTEXT (s->gui->textgad)->separator = prefs.show_separator;
 
 			if (fontchange)
-				gtk_xtext_set_font (GTK_XTEXT (s->gui->textgad), font_normal, 0);
+				gtk_xtext_set_font (GTK_XTEXT (s->gui->textgad), font_normal);
 
 			if (prefs.timestamp && prefs.indent_nicks)
 				GTK_XTEXT (s->gui->textgad)->time_stamp = TRUE;
@@ -729,8 +729,7 @@ settings_ok_clicked (GtkWidget * wid, struct session *sess)
 			GTK_XTEXT (s->gui->textgad)->separator = prefs.dialog_show_separator;
 
 			if (fontdialogchange)
-				gtk_xtext_set_font (GTK_XTEXT (s->gui->textgad), dialog_font_normal,
-									  0);
+				gtk_xtext_set_font (GTK_XTEXT (s->gui->textgad), dialog_font_normal);
 
 			if (prefs.timestamp && prefs.dialog_indent_nicks)
 				GTK_XTEXT (s->gui->textgad)->time_stamp = TRUE;
@@ -815,7 +814,7 @@ settings_ctree_select (GtkWidget * ctree, GtkCTreeNode * node)
 		return;
 
 	book = GTK_WIDGET (gtk_object_get_user_data (GTK_OBJECT (ctree)));
-	page = (gint) gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
+	page = GPOINTER_TO_INT (gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node));
 
 	gtk_notebook_set_page (GTK_NOTEBOOK (book), page);
 }
@@ -1435,8 +1434,13 @@ settings_page_irc (struct session *sess, GtkWidget * vbox)
 								  sizeof (prefs.partreason) - 1, tab,
 								  prefs.partreason,
 								  &sess->setup->entry_part, 0, 0, row_index++);
+#ifdef WIN32
+	gtkutil_label_new ("These can be a filename relative to <install dir>\\xchat\\data\\\n"
+							 "to be used as a list of random quit or part reasons.", wid);
+#else
 	gtkutil_label_new (_("These can be a filename relative to ~/.xchat/ to be\n"
 								"used as a list of random quit or part reasons."), wid);
+#endif
 
 	wid = settings_create_group (vbox, _("External Programs"));
 	tab = settings_create_table (wid);
@@ -1542,7 +1546,7 @@ settings_page_irc_away (struct session *sess, GtkWidget * vbox)
 			&(sess->setup->prefs.show_away_once));
 	add_tip (tog, _("Only show away messages the first time they're seen"));
 
-	tog = settings_create_toggle (_("Announce away messsages"), wid,
+	tog = settings_create_toggle (_("Announce away messages"), wid,
 			prefs.show_away_message, settings_ptoggle_check,
 			&(sess->setup->prefs.show_away_message));
 	add_tip (tog, _("Announce your away message to the channel(s) you are in"));
