@@ -2515,8 +2515,8 @@ gtk_xtext_load_trans (GtkXText * xtext)
 		gdk_gc_set_ts_origin (xtext->bgc, 0, 0);
 	} else
 	{
-#endif
 noshade:
+#endif
 		xtext->pixmap = gdk_pixmap_foreign_new (rootpix);
 		gdk_gc_set_tile (xtext->bgc, xtext->pixmap);
 		gdk_gc_set_ts_origin (xtext->bgc, -x, -y);
@@ -2760,7 +2760,7 @@ gtk_xtext_recalc_widths (GtkXText * xtext, int do_str_width)
 }
 
 void
-gtk_xtext_set_font (GtkXText * xtext, GdkFont * font, char *name)
+gtk_xtext_set_font (GtkXText * xtext, GdkFont * font)
 {
 	int i;
 #ifdef WIN32
@@ -2779,8 +2779,7 @@ gtk_xtext_set_font (GtkXText * xtext, GdkFont * font, char *name)
 	{
 		xtext->font = font;
 		gdk_font_ref (font);
-	} else
-		font = xtext->font = gdk_font_load (name);
+	}
 
 	if (!font)
 		font = xtext->font = gdk_font_load ("fixed");
@@ -2906,37 +2905,6 @@ gtk_xtext_set_background (GtkXText * xtext, GdkPixmap * pixmap, int trans,
 	}
 }
 
-#ifndef XCHAT
-
-gchar *
-gtk_xtext_get_chars (GtkXText * xtext)
-{
-	int lenght = 0;
-	gchar *chars;
-	textentry *tentry = xtext->text_first;
-	while (tentry != NULL)
-	{
-		lenght += tentry->str_len + 1;
-		tentry = tentry->next;
-	}
-	if (lenght == 0)
-		return NULL;
-	chars = g_malloc (lenght + 1);
-	*chars = 0;
-
-	tentry = xtext->text_first;
-	while (tentry != NULL)
-	{
-		strcat (chars, tentry->str);
-		strcat (chars, "\n");
-		tentry = tentry->next;
-	}
-
-	return chars;
-}
-
-#endif
-
 /* count how many lines 'ent' will take (with wraps) */
 
 static int
