@@ -106,39 +106,38 @@ fe_new_window (struct session *sess)
 				glib_major_version, glib_minor_version, glib_micro_version);
 	fe_print_text (sess, buf);
 
-	strcpy (buf, "\n\nCompiled in Features\0032:\017 ");
+	fe_print_text (sess, "\n\nCompiled in Features\0032:\017 "
 #ifdef USE_PERL
-	strcat (buf, "Perl ");
+	"Perl "
 #endif
 #ifdef USE_PYTHON
-	strcat (buf, "Python ");
+	"Python "
 #endif
 #ifdef USE_PLUGIN
-	strcat (buf, "Plugin ");
+	"Plugin "
 #endif
 #ifdef ENABLE_NLS
-	strcat (buf, "NLS ");
+	"NLS "
 #endif
 #ifdef USE_TRANS
-	strcat (buf, "Trans ");
+	"Trans "
 #endif
 #ifdef USE_HEBREW
-	strcat (buf, "Hebrew ");
+	"Hebrew "
 #endif
 #ifdef USE_OPENSSL
-	strcat (buf, "OpenSSL ");
+	"OpenSSL "
 #endif
 #ifdef SOCKS
-	strcat (buf, "Socks5 ");
+	"Socks5 "
 #endif
 #ifdef HAVE_ICONV
-	strcat (buf, "JCode ");
+	"JCode "
 #endif
 #ifdef USE_IPV6
-	strcat (buf, "IPv6 ");
+	"IPv6"
 #endif
-	strcat (buf, "\n\n");
-	fe_print_text (sess, buf);
+	"\n\n");
 	fflush (stdout);
 	fflush (stdin);
 }
@@ -160,7 +159,7 @@ timecat (char *buf)
 }
 
 /*                       0  1  2  3  4  5  6  7   8   9   10 11  12  13  14 15 */
-static int colconv[] = { 0, 7, 4, 2, 1, 3, 5, 11, 13, 12, 6, 16, 14, 15, 10, 7 };
+static const short colconv[] = { 0, 7, 4, 2, 1, 3, 5, 11, 13, 12, 6, 16, 14, 15, 10, 7 };
 
 void
 fe_print_text (struct session *sess, char *text)
